@@ -487,7 +487,12 @@ class IndicatedPushButton(QtWidgets.QPushButton, _HalWidgetBase):
     def connectSignals(self):
         def _update(state):
             self.setChecked(state)
-            if self._HAL_pin is False:
+            # linuxcnc status changes option uses _flip_state()
+            # hal pins option calls indicator_update() from
+            # HAL's value_changed callback set in _hal_init() function
+            # otherwise:
+            # update indicator to button state if halpin or status won't
+            if self._HAL_pin is False and self._ind_status is False:
                 self.indicator_update(state)
             # if using state labels option update the labels
             if self._state_text:
