@@ -6,6 +6,7 @@
 
 import gi
 from gi.repository import Gtk as gtk
+from gi.repository import Gdk as gdk
 from gi.repository import GObject as gobject
 from gi.repository import Pango as pango
 import hal
@@ -89,7 +90,7 @@ class HandlerClass:
             self.height = 0
             self.file_to_load = ""
             gobject.timeout_add(1000, self.clock)
-            self.default_theme = gtk.settings_get_default().get_property("gtk-theme-name")
+            self.default_theme = gtk.Settings.get_default().get_property("gtk-theme-name")
             self.label_home_x = self.widgets.btn_home_x.get_children()[0]
             self.label_home_y = self.widgets.btn_home_y.get_children()[0]
             self.label_home_z = self.widgets.btn_home_z.get_children()[0]
@@ -281,17 +282,19 @@ class HandlerClass:
         # set the button background colors and digits of the DRO
         self.homed_textcolor = self.gscreen.prefs.getpref("homed_textcolor", "#00FF00", str)     # default green
         self.unhomed_textcolor = self.gscreen.prefs.getpref("unhomed_textcolor", "#FF0000", str) # default red
-        self.widgets.homed_colorbtn.set_color(gdk.color_parse(self.homed_textcolor))
-        self.widgets.unhomed_colorbtn.set_color(gdk.color_parse(self.unhomed_textcolor))
-        self.homed_color = self.gscreen.convert_to_rgb(self.widgets.homed_colorbtn.get_color())
-        self.unhomed_color = self.gscreen.convert_to_rgb(self.widgets.unhomed_colorbtn.get_color())
-        self.widgets.tbtn_estop.modify_bg(gtk.STATE_NORMAL, gdk.color_parse("#00FF00"))
-        self.widgets.tbtn_estop.modify_bg(gtk.STATE_ACTIVE, gdk.color_parse("#FF0000"))
-        self.widgets.tbtn_on.modify_bg(gtk.STATE_NORMAL, gdk.color_parse("#FF0000"))
-        self.widgets.tbtn_on.modify_bg(gtk.STATE_ACTIVE, gdk.color_parse("#00FF00"))
-        self.label_home_x.modify_fg(gtk.STATE_NORMAL, gdk.color_parse("#FF0000"))
-        self.label_home_y.modify_fg(gtk.STATE_NORMAL, gdk.color_parse("#FF0000"))
-        self.label_home_z.modify_fg(gtk.STATE_NORMAL, gdk.color_parse("#FF0000"))
+        self.homed_color = gdk.RGBA()
+        self.homed_color.parse(self.homed_textcolor)
+        self.widgets.homed_colorbtn.set_rgba(self.homed_color)
+        self.unhomed_color = gdk.RGBA()
+        self.unhomed_color.parse(self.unhomed_textcolor)
+        self.widgets.unhomed_colorbtn.set_rgba(self.unhomed_color)
+        self.widgets.tbtn_estop.modify_bg(gtk.StateFlags.NORMAL, gdk.color_parse("#00FF00"))
+        self.widgets.tbtn_estop.modify_bg(gtk.StateFlags.ACTIVE, gdk.color_parse("#FF0000"))
+        self.widgets.tbtn_on.modify_bg(gtk.StateFlags.NORMAL, gdk.color_parse("#FF0000"))
+        self.widgets.tbtn_on.modify_bg(gtk.StateFlags.ACTIVE, gdk.color_parse("#00FF00"))
+        self.label_home_x.modify_fg(gtk.StateFlags.NORMAL, gdk.color_parse("#FF0000"))
+        self.label_home_y.modify_fg(gtk.StateFlags.NORMAL, gdk.color_parse("#FF0000"))
+        self.label_home_z.modify_fg(gtk.StateFlags.NORMAL, gdk.color_parse("#FF0000"))
         # set the active colours of togglebuttons and radiobuttons
         blue_list = ["tbtn_mist", "tbtn_flood", "tbtn_laser", "tbtn_spare",
                      "tbtn_units", "tbtn_pause",
@@ -302,11 +305,11 @@ class HandlerClass:
         other_list = ["rbt_view_p", "rbt_view_x", "rbt_view_y", "rbt_view_z",
                       "tbtn_view_dimension", "tbtn_view_tool_path"]
         for btn in blue_list:
-            self.widgets["{0}".format(btn)].modify_bg(gtk.STATE_ACTIVE, gdk.color_parse("#44A2CF"))
+            self.widgets["{0}".format(btn)].modify_bg(gtk.StateFlags.ACTIVE, gdk.color_parse("#44A2CF"))
         for btn in green_list:
-            self.widgets["{0}".format(btn)].modify_bg(gtk.STATE_ACTIVE, gdk.color_parse("#A2E592"))
+            self.widgets["{0}".format(btn)].modify_bg(gtk.StateFlags.ACTIVE, gdk.color_parse("#A2E592"))
         for btn in other_list:
-            self.widgets["{0}".format(btn)].modify_bg(gtk.STATE_ACTIVE, gdk.color_parse("#BB81B5"))
+            self.widgets["{0}".format(btn)].modify_bg(gtk.StateFlags.ACTIVE, gdk.color_parse("#BB81B5"))
 
     def init_sensitive_on_off(self):
         self.data.sensitive_on_off = ["table_run", "tbl_dro", "vbox_overrides",
@@ -346,7 +349,7 @@ class HandlerClass:
         try:
             self.stat.poll()
         except:
-            raise SystemExit, "SilverDragon cannot poll linuxcnc status any more"
+            raise SystemExit("SilverDragon cannot poll linuxcnc status any more")
         error = self.error_channel.poll()
         if error:
             self.gscreen.notify(_("ERROR"), _(error), ALERT_ICON)
@@ -860,12 +863,10 @@ class HandlerClass:
                 self.gscreen.prefs.putpref("audio_alert", file)
 
     def on_homed_colorbtn_color_set(self, widget):
-        self.homed_color = self.gscreen.convert_to_rgb(widget.get_color())
-        self.gscreen.prefs.putpref('homed_textcolor', widget.get_color(), str)
+        self.gscreen.prefs.putpref('homed_textcolor', gdk.RGBA.to_string(widget.get_rgba()), str)
 
     def on_unhomed_colorbtn_color_set(self, widget):
-        self.unhomed_color = self.gscreen.convert_to_rgb(widget.get_color())
-        self.gscreen.prefs.putpref('unhomed_textcolor', widget.get_color(), str)
+        self.gscreen.prefs.putpref('unhomed_textcolor', gdk.RGBA.to_string(widget.get_rgba()), str)
 
     def _from_internal_linear_unit(self, v, unit=None):
         if unit is None:
@@ -935,7 +936,7 @@ class HandlerClass:
         self.command.wait_complete()
         self.gscreen.sensitize_widgets(self.data.sensitive_all_homed, True)
         self.set_motion_mode(1)
-        self.widgets.statusbar1.remove_message(self.gscreen.statusbar_id, self.gscreen.homed_status_message)
+        self.widgets.statusbar1.remove(self.gscreen.statusbar_id, self.gscreen.homed_status_message)
         self.gscreen.notify(_("INFO"), _("All axes have been homed"), INFO_ICON)
         if self.widgets.chk_reload_tool.get_active():
             if self.stat.tool_in_spindle == 0:
@@ -1293,20 +1294,13 @@ class HandlerClass:
         j = 0
         for i in self.data.axis_list:
             if self.stat.joint[j]['homed']:
-                self["label_home_%s"%i].modify_fg(gtk.STATE_NORMAL, gdk.color_parse("#0000FF"))
+                self["label_home_%s"%i].modify_fg(gtk.StateFlags.NORMAL, gdk.color_parse("#0000FF"))
                 color = self.homed_color
             else:
-                self["label_home_%s"%i].modify_fg(gtk.STATE_NORMAL, gdk.color_parse("#FF0000"))
+                self["label_home_%s"%i].modify_fg(gtk.StateFlags.NORMAL, gdk.color_parse("#FF0000"))
                 color = self.unhomed_color
             j += 1
-            attr = pango.AttrList()
-            fg_color = pango.AttrForeground(color[0],color[1],color[2], 0, 11)
-            size = pango.AttrSize(22000, 0, -1)
-            weight = pango.AttrWeight(600, 0, -1)
-            attr.insert(fg_color)
-            attr.insert(size)
-            attr.insert(weight)
-            self.widgets["hal_dro_%s"%i].set_attributes(attr)
+            self.widgets["hal_dro_%s"%i].override_color(gtk.StateFlags.NORMAL, color)
 
     def _set_spindle(self, command):
         if self.stat.task_state == linuxcnc.STATE_ESTOP:
@@ -1444,7 +1438,7 @@ class HandlerClass:
             self.widgets.offsetpage1.machine_units_mm = _INCH
         self.widgets.offsetpage1.set_row_visible("1", False)
         self.widgets.offsetpage1.set_font("sans 12")
-        self.widgets.offsetpage1.set_foreground_color("#28D0D9")
+        self.widgets.offsetpage1.set_foreground_color(gdk.RGBA(0.151, 0.813, 0.845, 1.0))
         self.widgets.offsetpage1.selection_mask = ("Tool", "G5x", "Rot")
         systemlist = ["Tool", "G5x", "Rot", "G92", "G54", "G55", "G56", "G57", "G58", "G59", "G59.1",
                       "G59.2", "G59.3"]
