@@ -81,14 +81,14 @@ int main(int argc, char **argv)
         ERR(gbl.init_dbg, "Unable to create HAL pins");
         goto QUIT_CLEANUP;
     }
-    hal_ready(gbl.hal_mod_id);
-    OK(gbl.init_dbg, "HAL components created OK");
-
-    gbl.quit_flag = 0; //tell the threads to quit (SIGTERM o SIGQUIT) (unloadusr mb2hal).
+    gbl.quit_flag = 0; //tell the threads to quit (SIGTERM or SIGINT) (unloadusr mb2hal).
     signal(SIGINT, quit_signal);
     //unloadusr and unload commands of halrun
     signal(SIGTERM, quit_signal);
 
+    hal_ready(gbl.hal_mod_id);
+    OK(gbl.init_dbg, "HAL components created OK");
+
     /* Each link has it's own thread */
     pthread_attr_init(&thrd_attr);
     for (counter = 0; counter < gbl.tot_mb_links; counter++) {
@@ -149,7 +149,7 @@ void *link_loop_and_logic(void *thrd_link_num)
 
         for (tx_counter = 0; tx_counter < gbl.tot_mb_tx; tx_counter++) {
 
-            if (gbl.quit_flag != 0) { //tell the threads to quit (SIGTERM o SGIQUIT) (unloadusr mb2hal).
+            if (gbl.quit_flag != 0) {
                 return NULL;
             }
 
@@ -225,7 +225,7 @@ void *link_loop_and_logic(void *thrd_link_num)
                 break;
             }
 
-            if (gbl.quit_flag != 0) { //tell the threads to quit (SIGTERM o SGIQUIT) (unloadusr mb2hal).
+            if (gbl.quit_flag != 0) {
                 return NULL;
             }
 
@@ -441,7 +441,7 @@ void quit_signal(int signal)
 {
     char *fnct_name = "quit_signal";
 
-    gbl.quit_flag = 1; //tell the threads to quit (SIGTERM o SIGQUIT) (unloadusr mb2hal).
+    gbl.quit_flag = 1; //tell the threads to quit (SIGTERM or SIGINT) (unloadusr mb2hal).
     DBG(gbl.init_dbg, "signal [%d] received", signal);
 }
 
